
# Slot: source_data


Compressed input data for pipeline (tar.gz).

URI: [https://w3id.org/neat/graphDataConfiguration__source_data](https://w3id.org/neat/graphDataConfiguration__source_data)


## Domain and Range

None &#8594;  <sub>0..1</sub> [FileResourceContainer](FileResourceContainer.md)

## Parents


## Children


## Used by

 * [GraphDataConfiguration](GraphDataConfiguration.md)
